@@ -7,7 +7,7 @@ import requests
 from .domain import FlowName, JobBuildNumber, AgentToken, Job, ServerUrl, AgentJobDir
 
 HttpHeaderWithJson = {
-    "Content-Type": "application/json"
+    "Content-Type": "application/json",
     "AGENT-TOKEN": AgentToken
 }
 
@@ -77,10 +77,18 @@ class Client:
             print(e)
             return None
 
-    def sendJobReport(self, path, body):
+    def sendJobReport(self, path, name, zipped, contentType, entryFile=""):
         try:
             url = "{}/api/flow/{}/job/{}/report".format(
                 ServerUrl, FlowName, JobBuildNumber)
+
+            body = {
+                "name": name,
+                "zipped": zipped,
+                "type": contentType,
+                "entryFile": entryFile
+            }
+
             r = requests.post(url=url, headers=HttpHeaders, files={
                 'file': open(path, 'rb'),
                 'body': ('', json.dumps(body), 'application/json')
@@ -90,6 +98,20 @@ class Client:
             print(e)
             return -1
 
+    def uploadJobArtifact(self, path):
+        try:
+            url = "{}/api/flow/{}/job/{}/artifact".format(
+                ServerUrl, FlowName, JobBuildNumber)
+
+            r = requests.post(url=url, headers=HttpHeaders, files={
+                'file': open(path, 'rb')
+            })
+
+            return r.status_code
+        except Exception as e:
+            print(e)
+            return -1
+
     def sendStatistic(self, body):
         try:
             url = "{}/api/flow/{}/stats".format(ServerUrl, FlowName)
